export import rt = require("raml-typesystem");
import typeSystem = rt.nominalTypes;
export declare type IHighLevelNode = any;
export declare type IParseResult = any;
export declare type Named = typeSystem.NamedId;
export declare var injector: {
    inject(a: typeSystem.Adaptable): void;
};
export declare type IType = typeSystem.ITypeDefinition;
export declare type ITypeDefinition = typeSystem.ITypeDefinition;
export declare type IProperty = typeSystem.IProperty;
export declare class AbstractType extends typeSystem.AbstractType implements typeSystem.ITypeDefinition {
}
export declare class ValueType extends typeSystem.ValueType implements IType {
}
export declare class EnumType extends ValueType {
    values: string[];
}
export interface IValueDocProvider {
    (v: string): string;
}
export interface IValueSuggester {
    (node: IHighLevelNode): string[];
}
export declare class ReferenceType extends ValueType {
    private referenceTo;
    constructor(name: string, path: string, referenceTo: string, _universe: Universe);
    getReferencedType(): NodeClass;
    hasStructure(): boolean;
}
export declare class NodeClass extends typeSystem.StructuredType implements IType, typeSystem.ITypeDefinition {
    constructor(_name: string, universe: Universe, path: string, _description?: string);
    allProperties(v?: {
        [name: string]: typeSystem.ITypeDefinition;
    }): Property[];
}
export declare class UserDefinedClass extends NodeClass {
    key(): any;
    isUserDefined(): boolean;
    typeId(): string;
    constructor(name: string, universe: Universe, hl: IHighLevelNode, path: string, description: string);
    _value: boolean;
    hasValueTypeInHierarchy(): boolean;
    isGenuineUserDefinedType(): boolean;
    genuineUserDefinedType(): typeSystem.ITypeDefinition;
}
export declare class AnnotationType extends UserDefinedClass {
    allProperties(ps?: {
        [name: string]: typeSystem.ITypeDefinition;
    }): Property[];
    isAnnotationType(): boolean;
}
export interface IUniverseDescriptor {
    [name: string]: typeSystem.NamedId;
}
export declare class Universe extends typeSystem.Described implements typeSystem.IUniverse {
    private _parent;
    private _classes;
    private _uversion;
    private _topLevel;
    private matchedObjects;
    private _typedVersion;
    matched(): IUniverseDescriptor;
    setTopLevel(t: string): void;
    getTopLevel(): string;
    setTypedVersion(tv: string): void;
    getTypedVersion(): string;
    version(): string;
    setUniverseVersion(version: string): void;
    types(): IType[];
    type(name: string): ITypeDefinition;
    register(t: IType): this;
    private aMap;
    registerAlias(a: string, t: IType): void;
    unregister(t: IType): this;
    constructor(dec: IUniverseDescriptor, name?: string, _parent?: Universe, v?: string);
    registerSuperClass(t0: IType, t1: IType): void;
}
export declare function prop(name: string, desc: string, domain: NodeClass, range: IType, custom?: boolean): Property;
export declare class ChildValueConstraint {
    name: string;
    value: string;
    constructor(name: string, value: string);
}
export declare class Property extends typeSystem.Property implements typeSystem.IProperty {
    private _isFromParentValue;
    private _isFromParentKey;
    private _key;
    private _declaresFields;
    private _describes;
    private _inheritsValueFromContext;
    private _canBeDuplicator;
    private _allowsNull;
    private _canBeValue;
    private _isInherited;
    private _oftenKeys;
    private _vprovider;
    private _suggester;
    private _selfNode;
    private _noDirectParse;
    isPrimitive(): boolean;
    withNoDirectParse(): void;
    isNoDirectParse(): boolean;
    withSelfNode(): void;
    isSelfNode(): boolean;
    matchKey(k: string): boolean;
    valueDocProvider(): IValueDocProvider;
    setValueDocProvider(v: IValueDocProvider): this;
    suggester(): IValueSuggester;
    setValueSuggester(s: IValueSuggester): void;
    enumOptions(): string[];
    getOftenKeys(): string[];
    withOftenKeys(keys: string[]): this;
    withCanBeValue(): this;
    withInherited(w: boolean): void;
    isInherited(): boolean;
    isAllowNull(): boolean;
    withAllowNull(): void;
    getCanBeDuplicator(): boolean;
    canBeValue(): boolean;
    setCanBeDuplicator(): boolean;
    inheritedContextValue(): string;
    withInheritedContextValue(v: string): this;
    private _contextReq;
    withContextRequirement(name: string, value: string): void;
    getContextRequirements(): {
        name: string;
        value: string;
    }[];
    withDescribes(a: string): this;
    describesAnnotation(): boolean;
    describedAnnotation(): string;
    private _newInstanceName;
    isReference(): boolean;
    referencesTo(): IType;
    newInstanceName(): string;
    withThisPropertyDeclaresFields(b?: boolean): this;
    isThisPropertyDeclaresTypeFields(): boolean;
    withNewInstanceName(name: string): this;
    private determinesChildValues;
    addChildValueConstraint(c: ChildValueConstraint): void;
    getChildValueConstraints(): ChildValueConstraint[];
    childRestrictions(): {
        name: string;
        value: any;
    }[];
    _id: any;
    id(): any;
    isAnnotation(): boolean;
    withFromParentValue(v?: boolean): this;
    withFromParentKey(v?: boolean): this;
    isFromParentKey(): boolean;
    isFromParentValue(): boolean;
    withGroupName(gname: string): this;
    unmerge(): this;
    merge(): this;
    withKey(isKey: boolean): this;
    isKey(): boolean;
    isMerged(): boolean;
    groupName(): string;
    key(): typeSystem.NamedId;
}
export declare type Array = typeSystem.Array;
export declare class UserDefinedProp extends Property {
    _node: IParseResult;
    _displayName: string;
    withDisplayName(name: string): void;
    getDisplayName(): string;
    node(): any;
}
export declare class RAMLPropertyDocumentationService {
    private _markdownDescription;
    private _documentationTableName;
    private _isHidden;
    private _valueDescription;
    setDocTableName(val: string): void;
    docTableName(): string;
    setHidden(val: boolean): void;
    isHidden(): boolean;
    setMarkdownDescription(val: string): void;
    markdownDescription(): string;
    setValueDescription(val: string): void;
    valueDescription(): string;
}
export declare class RAMLPropertyParserService extends RAMLPropertyDocumentationService {
    private _isEmbededMap;
    private _isSystemProperty;
    isSystem(): boolean;
    withSystem(s: boolean): this;
    isEmbedMap(): boolean;
    withEmbedMap(): this;
}
export declare class RAMLPropertyService extends RAMLPropertyParserService {
    private _property;
    constructor(_property: IProperty);
    valueDocProvider(): IValueDocProvider;
    private _propertyGrammarType;
    withPropertyGrammarType(pt: string): void;
    getPropertyGrammarType(): string;
    id(): string;
    range(): ITypeDefinition;
    domain(): ITypeDefinition;
    isAllowNull(): boolean;
    referencesTo(): ITypeDefinition;
    isReference(): boolean;
    texpr: boolean;
    nameId(): string;
    priority(): number;
    isKey(): boolean;
    isMerged(): boolean;
    isTypeExpr(): boolean;
    isExampleProperty(): boolean;
    example: boolean;
    setExample(e: boolean): void;
    setTypeExpression(e: boolean): void;
    isDescriminating(): boolean;
}
export interface ValueRequirement {
    name: string;
    value: string;
}
export declare class RAMLService {
    private _node;
    private _type;
    private _representationOf;
    private _allowsAnyChildren;
    private _allowsOptionalProperties;
    withAllowQuestion(): void;
    getAllowQuestion(): boolean;
    private _canInherit;
    withCanInherit(clazz: string): void;
    private _referenceIs;
    getReferenceIs(): string;
    withReferenceIs(fname: string): void;
    descriminatorValue(): string;
    getCanInherit(): string[];
    withAllowAny(): void;
    getAllowAny(): boolean;
    private _declaredBy;
    globallyDeclaredBy(): NodeClass[];
    setGloballyDeclaredBy(c: NodeClass): void;
    setDeclaringNode(n: any): void;
    nameId(): string;
    universe(): Universe;
    isAssignableFrom(name: string): boolean;
    _aliases: string[];
    _consumesRef: boolean;
    _defining: string[];
    setConsumesRefs(b: boolean): void;
    definingPropertyIsEnough(v: string): void;
    getDefining(): string[];
    getConsumesRefs(): boolean;
    private _fDesc;
    addAlias(al: string): void;
    getAliases(): string[];
    valueRequirements(): ValueRequirement[];
    private _allowsValueSet;
    private _allowsValue;
    private _isAnnotation;
    private _annotationChecked;
    private _actuallyExports;
    isAnnotation(): boolean;
    allowValue(): boolean;
    key(): Named;
    getRepresentationOf(): ITypeDefinition;
    constructor(d: ITypeDefinition);
    getPath(): string;
    isDeclaration(): boolean;
    isGlobalDeclaration(): boolean;
    isTypeSystemMember(): boolean;
    getExtendedType(): ITypeDefinition;
    private _runtimeExtenders;
    setInlinedTemplates(b: boolean): this;
    getRuntimeExtenders(): ITypeDefinition[];
    isInlinedTemplates(): boolean;
    setExtendedTypeName(name: string): void;
    getKeyProp(): IProperty;
    private _declaresType;
    private _convertsToGlobal;
    private _isTemplate;
    withActuallyExports(pname: string): void;
    withConvertsToGlobal(pname: string): void;
    getConvertsToGlobal(): string;
    getActuallyExports(): string;
    isUserDefined(): boolean;
    private _contextRequirements;
    withContextRequirement(name: string, value: string): void;
    getContextRequirements(): {
        name: string;
        value: string;
    }[];
    findMembersDeterminer(): IProperty;
    getDeclaringNode(): any;
    registerSupertypes(classNames: string[]): void;
}
export declare var universesInfo: {
    "Universe08": {
        "GlobalSchema": {
            "name": string;
            "properties": {
                "key": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
            };
        };
        "Api": {
            "name": string;
            "properties": {
                "title": {
                    "name": string;
                };
                "version": {
                    "name": string;
                };
                "baseUri": {
                    "name": string;
                };
                "baseUriParameters": {
                    "name": string;
                };
                "uriParameters": {
                    "name": string;
                };
                "protocols": {
                    "name": string;
                };
                "mediaType": {
                    "name": string;
                };
                "schemas": {
                    "name": string;
                };
                "traits": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "securitySchemes": {
                    "name": string;
                };
                "resourceTypes": {
                    "name": string;
                };
                "resources": {
                    "name": string;
                };
                "documentation": {
                    "name": string;
                };
                "RAMLVersion": {
                    "name": string;
                };
            };
        };
        "DocumentationItem": {
            "name": string;
            "properties": {
                "title": {
                    "name": string;
                };
                "content": {
                    "name": string;
                };
            };
        };
        "ValueType": {
            "name": string;
            "properties": {};
        };
        "StringType": {
            "name": string;
            "properties": {};
        };
        "AnyType": {
            "name": string;
            "properties": {};
        };
        "NumberType": {
            "name": string;
            "properties": {};
        };
        "BooleanType": {
            "name": string;
            "properties": {};
        };
        "Referencable": {
            "name": string;
            "properties": {};
        };
        "Reference": {
            "name": string;
            "properties": {
                "structuredValue": {
                    "name": string;
                };
                "name": {
                    "name": string;
                };
            };
        };
        "DeclaresDynamicType": {
            "name": string;
            "properties": {};
        };
        "UriTemplate": {
            "name": string;
            "properties": {};
        };
        "RelativeUriString": {
            "name": string;
            "properties": {};
        };
        "FullUriTemplateString": {
            "name": string;
            "properties": {};
        };
        "FixedUri": {
            "name": string;
            "properties": {};
        };
        "MarkdownString": {
            "name": string;
            "properties": {};
        };
        "SchemaString": {
            "name": string;
            "properties": {};
        };
        "JSonSchemaString": {
            "name": string;
            "properties": {};
        };
        "XMLSchemaString": {
            "name": string;
            "properties": {};
        };
        "ExampleString": {
            "name": string;
            "properties": {};
        };
        "StatusCodeString": {
            "name": string;
            "properties": {};
        };
        "JSONExample": {
            "name": string;
            "properties": {};
        };
        "XMLExample": {
            "name": string;
            "properties": {};
        };
        "TypeInstance": {
            "name": string;
            "properties": {
                "properties": {
                    "name": string;
                };
                "isScalar": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
            };
        };
        "TypeInstanceProperty": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
                "values": {
                    "name": string;
                };
                "isArray": {
                    "name": string;
                };
            };
        };
        "RAMLLanguageElement": {
            "name": string;
            "properties": {
                "description": {
                    "name": string;
                };
            };
        };
        "RAMLSimpleElement": {
            "name": string;
            "properties": {};
        };
        "ResourceTypeRef": {
            "name": string;
            "properties": {
                "resourceType": {
                    "name": string;
                };
            };
        };
        "TraitRef": {
            "name": string;
            "properties": {
                "trait": {
                    "name": string;
                };
            };
        };
        "MethodBase": {
            "name": string;
            "properties": {
                "responses": {
                    "name": string;
                };
                "body": {
                    "name": string;
                };
                "protocols": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
            };
        };
        "Trait": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "usage": {
                    "name": string;
                };
                "parametrizedProperties": {
                    "name": string;
                };
            };
        };
        "ResourceType": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "usage": {
                    "name": string;
                };
                "methods": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "uriParameters": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "baseUriParameters": {
                    "name": string;
                };
                "parametrizedProperties": {
                    "name": string;
                };
            };
        };
        "Method": {
            "name": string;
            "properties": {
                "method": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
            };
        };
        "Resource": {
            "name": string;
            "properties": {
                "relativeUri": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "uriParameters": {
                    "name": string;
                };
                "methods": {
                    "name": string;
                };
                "resources": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "baseUriParameters": {
                    "name": string;
                };
            };
        };
        "SecuritySchemePart": {
            "name": string;
            "properties": {
                "headers": {
                    "name": string;
                };
                "queryParameters": {
                    "name": string;
                };
                "responses": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
            };
        };
        "SecuritySchemeSettings": {
            "name": string;
            "properties": {};
        };
        "AbstractSecurityScheme": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "describedBy": {
                    "name": string;
                };
                "settings": {
                    "name": string;
                };
            };
        };
        "SecuritySchemeRef": {
            "name": string;
            "properties": {
                "securitySchemeName": {
                    "name": string;
                };
                "securityScheme": {
                    "name": string;
                };
            };
        };
        "OAuth1SecuritySchemeSettings": {
            "name": string;
            "properties": {
                "requestTokenUri": {
                    "name": string;
                };
                "authorizationUri": {
                    "name": string;
                };
                "tokenCredentialsUri": {
                    "name": string;
                };
            };
        };
        "OAuth2SecuritySchemeSettings": {
            "name": string;
            "properties": {
                "accessTokenUri": {
                    "name": string;
                };
                "authorizationUri": {
                    "name": string;
                };
                "authorizationGrants": {
                    "name": string;
                };
                "scopes": {
                    "name": string;
                };
            };
        };
        "OAuth2SecurityScheme": {
            "name": string;
            "properties": {
                "settings": {
                    "name": string;
                };
            };
        };
        "OAuth1SecurityScheme": {
            "name": string;
            "properties": {
                "settings": {
                    "name": string;
                };
            };
        };
        "BasicSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "DigestSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "CustomSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "Parameter": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "location": {
                    "name": string;
                };
                "required": {
                    "name": string;
                };
                "default": {
                    "name": string;
                };
                "example": {
                    "name": string;
                };
                "repeat": {
                    "name": string;
                };
            };
        };
        "StringTypeDeclaration": {
            "name": string;
            "properties": {
                "pattern": {
                    "name": string;
                };
                "enum": {
                    "name": string;
                };
                "minLength": {
                    "name": string;
                };
                "maxLength": {
                    "name": string;
                };
            };
        };
        "BooleanTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "NumberTypeDeclaration": {
            "name": string;
            "properties": {
                "minimum": {
                    "name": string;
                };
                "maximum": {
                    "name": string;
                };
            };
        };
        "IntegerTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "DateTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "FileTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "HasNormalParameters": {
            "name": string;
            "properties": {
                "queryParameters": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "headers": {
                    "name": string;
                };
            };
        };
        "ParameterLocation": {
            "name": string;
            "properties": {};
        };
        "MimeTypeModel": {
            "name": string;
            "properties": {
                "type": {
                    "name": string;
                };
                "tree": {
                    "name": string;
                };
                "subtype": {
                    "name": string;
                };
                "suffix": {
                    "name": string;
                };
                "parameters": {
                    "name": string;
                };
            };
        };
        "MimeType": {
            "name": string;
            "properties": {};
        };
        "BodyLike": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "schema": {
                    "name": string;
                };
                "example": {
                    "name": string;
                };
                "formParameters": {
                    "name": string;
                };
                "schemaContent": {
                    "name": string;
                };
            };
        };
        "XMLBody": {
            "name": string;
            "properties": {
                "schema": {
                    "name": string;
                };
            };
        };
        "JSONBody": {
            "name": string;
            "properties": {
                "schema": {
                    "name": string;
                };
            };
        };
        "Response": {
            "name": string;
            "properties": {
                "code": {
                    "name": string;
                };
                "headers": {
                    "name": string;
                };
                "body": {
                    "name": string;
                };
            };
        };
    };
    "Universe10": {
        "GlobalSchema": {
            "name": string;
            "properties": {
                "key": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
            };
        };
        "ImportDeclaration": {
            "name": string;
            "properties": {
                "key": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
            };
        };
        "Library": {
            "name": string;
            "properties": {
                "usage": {
                    "name": string;
                };
                "name": {
                    "name": string;
                };
            };
        };
        "LibraryBase": {
            "name": string;
            "properties": {
                "schemas": {
                    "name": string;
                };
                "types": {
                    "name": string;
                };
                "traits": {
                    "name": string;
                };
                "resourceTypes": {
                    "name": string;
                };
                "annotationTypes": {
                    "name": string;
                };
                "securitySchemes": {
                    "name": string;
                };
                "uses": {
                    "name": string;
                };
            };
        };
        "Overlay": {
            "name": string;
            "properties": {
                "usage": {
                    "name": string;
                };
                "masterRef": {
                    "name": string;
                };
                "title": {
                    "name": string;
                };
            };
        };
        "Extension": {
            "name": string;
            "properties": {
                "usage": {
                    "name": string;
                };
                "masterRef": {
                    "name": string;
                };
                "title": {
                    "name": string;
                };
            };
        };
        "Api": {
            "name": string;
            "properties": {
                "title": {
                    "name": string;
                };
                "version": {
                    "name": string;
                };
                "baseUri": {
                    "name": string;
                };
                "baseUriParameters": {
                    "name": string;
                };
                "protocols": {
                    "name": string;
                };
                "mediaType": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "resources": {
                    "name": string;
                };
                "documentation": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
                "RAMLVersion": {
                    "name": string;
                };
            };
        };
        "DocumentationItem": {
            "name": string;
            "properties": {
                "title": {
                    "name": string;
                };
                "content": {
                    "name": string;
                };
            };
        };
        "ValueType": {
            "name": string;
            "properties": {};
        };
        "StringType": {
            "name": string;
            "properties": {};
        };
        "AnyType": {
            "name": string;
            "properties": {};
        };
        "NumberType": {
            "name": string;
            "properties": {};
        };
        "BooleanType": {
            "name": string;
            "properties": {};
        };
        "Referencable": {
            "name": string;
            "properties": {};
        };
        "Reference": {
            "name": string;
            "properties": {
                "structuredValue": {
                    "name": string;
                };
                "name": {
                    "name": string;
                };
            };
        };
        "DeclaresDynamicType": {
            "name": string;
            "properties": {};
        };
        "UriTemplate": {
            "name": string;
            "properties": {};
        };
        "StatusCodeString": {
            "name": string;
            "properties": {};
        };
        "RelativeUriString": {
            "name": string;
            "properties": {};
        };
        "FullUriTemplateString": {
            "name": string;
            "properties": {};
        };
        "FixedUriString": {
            "name": string;
            "properties": {};
        };
        "ContentType": {
            "name": string;
            "properties": {};
        };
        "ValidityExpression": {
            "name": string;
            "properties": {};
        };
        "MarkdownString": {
            "name": string;
            "properties": {};
        };
        "DateFormatSpec": {
            "name": string;
            "properties": {};
        };
        "FunctionalInterface": {
            "name": string;
            "properties": {};
        };
        "SchemaString": {
            "name": string;
            "properties": {};
        };
        "ExampleString": {
            "name": string;
            "properties": {};
        };
        "JSonSchemaString": {
            "name": string;
            "properties": {};
        };
        "XMLSchemaString": {
            "name": string;
            "properties": {};
        };
        "RAMLSelector": {
            "name": string;
            "properties": {};
        };
        "ExampleSpec": {
            "name": string;
            "properties": {
                "content": {
                    "name": string;
                };
                "strict": {
                    "name": string;
                };
                "name": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
                "structuredContent": {
                    "name": string;
                };
            };
        };
        "DataElementProperty": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "location": {
                    "name": string;
                };
                "locationKind": {
                    "name": string;
                };
                "default": {
                    "name": string;
                };
                "required": {
                    "name": string;
                };
            };
        };
        "TypeDeclaration": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "facets": {
                    "name": string;
                };
                "schema": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "location": {
                    "name": string;
                };
                "locationKind": {
                    "name": string;
                };
                "default": {
                    "name": string;
                };
                "example": {
                    "name": string;
                };
                "examples": {
                    "name": string;
                };
                "repeat": {
                    "name": string;
                };
                "required": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
                "fixedFacets": {
                    "name": string;
                };
                "schemaContent": {
                    "name": string;
                };
                "structuredExample": {
                    "name": string;
                };
            };
        };
        "ScalarElement": {
            "name": string;
            "properties": {
                "facets": {
                    "name": string;
                };
                "enum": {
                    "name": string;
                };
            };
        };
        "ArrayTypeDeclaration": {
            "name": string;
            "properties": {
                "uniqueItems": {
                    "name": string;
                };
                "items": {
                    "name": string;
                };
                "minItems": {
                    "name": string;
                };
                "maxItems": {
                    "name": string;
                };
            };
        };
        "UnionTypeDeclaration": {
            "name": string;
            "properties": {
                "discriminator": {
                    "name": string;
                };
            };
        };
        "ObjectTypeDeclaration": {
            "name": string;
            "properties": {
                "properties": {
                    "name": string;
                };
                "minProperties": {
                    "name": string;
                };
                "maxProperties": {
                    "name": string;
                };
                "additionalProperties": {
                    "name": string;
                };
                "patternProperties": {
                    "name": string;
                };
                "discriminator": {
                    "name": string;
                };
                "discriminatorValue": {
                    "name": string;
                };
            };
        };
        "StringTypeDeclaration": {
            "name": string;
            "properties": {
                "pattern": {
                    "name": string;
                };
                "minLength": {
                    "name": string;
                };
                "maxLength": {
                    "name": string;
                };
                "enum": {
                    "name": string;
                };
            };
        };
        "BooleanTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "ValueTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "NumberTypeDeclaration": {
            "name": string;
            "properties": {
                "minimum": {
                    "name": string;
                };
                "maximum": {
                    "name": string;
                };
                "enum": {
                    "name": string;
                };
                "format": {
                    "name": string;
                };
                "multipleOf": {
                    "name": string;
                };
            };
        };
        "IntegerTypeDeclaration": {
            "name": string;
            "properties": {
                "format": {
                    "name": string;
                };
            };
        };
        "RAMLExpression": {
            "name": string;
            "properties": {};
        };
        "SchemaElement": {
            "name": string;
            "properties": {};
        };
        "DateTypeDeclaration": {
            "name": string;
            "properties": {
                "dateFormat": {
                    "name": string;
                };
            };
        };
        "TypeInstance": {
            "name": string;
            "properties": {
                "properties": {
                    "name": string;
                };
                "isScalar": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
            };
        };
        "TypeInstanceProperty": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "value": {
                    "name": string;
                };
                "values": {
                    "name": string;
                };
                "isArray": {
                    "name": string;
                };
            };
        };
        "ModelLocation": {
            "name": string;
            "properties": {};
        };
        "LocationKind": {
            "name": string;
            "properties": {};
        };
        "MimeTypeModel": {
            "name": string;
            "properties": {
                "type": {
                    "name": string;
                };
                "tree": {
                    "name": string;
                };
                "subtype": {
                    "name": string;
                };
                "suffix": {
                    "name": string;
                };
                "parameters": {
                    "name": string;
                };
            };
        };
        "MimeType": {
            "name": string;
            "properties": {};
        };
        "Response": {
            "name": string;
            "properties": {
                "code": {
                    "name": string;
                };
                "headers": {
                    "name": string;
                };
                "body": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
            };
        };
        "RAMLLanguageElement": {
            "name": string;
            "properties": {
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
            };
        };
        "RAMLSimpleElement": {
            "name": string;
            "properties": {};
        };
        "AnnotationTypeDeclaration": {
            "name": string;
            "properties": {
                "allowMultiple": {
                    "name": string;
                };
                "allowedTargets": {
                    "name": string;
                };
                "usage": {
                    "name": string;
                };
            };
        };
        "AnnotationRef": {
            "name": string;
            "properties": {
                "annotation": {
                    "name": string;
                };
            };
        };
        "AnnotationTarget": {
            "name": string;
            "properties": {};
        };
        "Annotation": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
            };
        };
        "ArrayAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "UnionAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "ObjectAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "StringAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "BooleanAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "ValueAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "NumberAnnotationTypeDeclaration": {
            "name": string;
            "properties": {};
        };
        "RAMLExpressionAnnotation": {
            "name": string;
            "properties": {};
        };
        "DateTypeAnnotationDeclaration": {
            "name": string;
            "properties": {};
        };
        "ResourceTypeRef": {
            "name": string;
            "properties": {
                "resourceType": {
                    "name": string;
                };
            };
        };
        "TraitRef": {
            "name": string;
            "properties": {
                "trait": {
                    "name": string;
                };
            };
        };
        "SecuritySchemePart": {
            "name": string;
            "properties": {
                "headers": {
                    "name": string;
                };
                "queryParameters": {
                    "name": string;
                };
                "queryString": {
                    "name": string;
                };
                "responses": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
            };
        };
        "SecuritySchemeSettings": {
            "name": string;
            "properties": {};
        };
        "OAuth1SecuritySchemeSettings": {
            "name": string;
            "properties": {
                "requestTokenUri": {
                    "name": string;
                };
                "authorizationUri": {
                    "name": string;
                };
                "tokenCredentialsUri": {
                    "name": string;
                };
                "signatures": {
                    "name": string;
                };
            };
        };
        "OAuth2SecuritySchemeSettings": {
            "name": string;
            "properties": {
                "accessTokenUri": {
                    "name": string;
                };
                "authorizationUri": {
                    "name": string;
                };
                "authorizationGrants": {
                    "name": string;
                };
                "scopes": {
                    "name": string;
                };
            };
        };
        "PassThroughSecuritySchemeSettings": {
            "name": string;
            "properties": {
                "queryParameterName": {
                    "name": string;
                };
                "headerName": {
                    "name": string;
                };
            };
        };
        "SecuritySchemeRef": {
            "name": string;
            "properties": {
                "securitySchemeName": {
                    "name": string;
                };
                "securityScheme": {
                    "name": string;
                };
            };
        };
        "AbstractSecurityScheme": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "describedBy": {
                    "name": string;
                };
                "settings": {
                    "name": string;
                };
            };
        };
        "OAuth2SecurityScheme": {
            "name": string;
            "properties": {
                "settings": {
                    "name": string;
                };
            };
        };
        "OAuth1SecurityScheme": {
            "name": string;
            "properties": {
                "settings": {
                    "name": string;
                };
            };
        };
        "PassThroughSecurityScheme": {
            "name": string;
            "properties": {
                "settings": {
                    "name": string;
                };
            };
        };
        "BasicSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "DigestSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "CustomSecurityScheme": {
            "name": string;
            "properties": {};
        };
        "MethodBase": {
            "name": string;
            "properties": {
                "responses": {
                    "name": string;
                };
                "body": {
                    "name": string;
                };
                "protocols": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
            };
        };
        "Trait": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "usage": {
                    "name": string;
                };
                "uses": {
                    "name": string;
                };
                "parametrizedProperties": {
                    "name": string;
                };
            };
        };
        "ResourceBase": {
            "name": string;
            "properties": {
                "methods": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "type": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
                "uriParameters": {
                    "name": string;
                };
            };
        };
        "ResourceType": {
            "name": string;
            "properties": {
                "name": {
                    "name": string;
                };
                "usage": {
                    "name": string;
                };
                "uses": {
                    "name": string;
                };
                "parametrizedProperties": {
                    "name": string;
                };
            };
        };
        "ResourceTypeOrTrait": {
            "name": string;
            "properties": {
                "usage": {
                    "name": string;
                };
                "uses": {
                    "name": string;
                };
                "parameters": {
                    "name": string;
                };
            };
        };
        "Method": {
            "name": string;
            "properties": {
                "method": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "queryString": {
                    "name": string;
                };
                "queryParameters": {
                    "name": string;
                };
                "headers": {
                    "name": string;
                };
                "body": {
                    "name": string;
                };
                "is": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
                "securedBy": {
                    "name": string;
                };
            };
        };
        "Resource": {
            "name": string;
            "properties": {
                "relativeUri": {
                    "name": string;
                };
                "resources": {
                    "name": string;
                };
                "displayName": {
                    "name": string;
                };
                "description": {
                    "name": string;
                };
                "annotations": {
                    "name": string;
                };
            };
        };
        "FileTypeDeclaration": {
            "name": string;
            "properties": {
                "fileTypes": {
                    "name": string;
                };
                "minLength": {
                    "name": string;
                };
                "maxLength": {
                    "name": string;
                };
            };
        };
        "HasNormalParameters": {
            "name": string;
            "properties": {
                "queryParameters": {
                    "name": string;
                };
                "headers": {
                    "name": string;
                };
                "queryString": {
                    "name": string;
                };
            };
        };
        "Status": {
            "name": string;
            "properties": {
                "code": {
                    "name": string;
                };
                "message": {
                    "name": string;
                };
            };
        };
        "AuthentificationState": {
            "name": string;
            "properties": {};
        };
        "AuthentificationParameters": {
            "name": string;
            "properties": {};
        };
        "AuthData": {
            "name": string;
            "properties": {
                "authentificationParameters": {
                    "name": string;
                };
            };
        };
        "ParameterSpec": {
            "name": string;
            "properties": {};
        };
        "PromptSpec": {
            "name": string;
            "properties": {};
        };
        "UserResponse": {
            "name": string;
            "properties": {};
        };
        "QueryListener": {
            "name": string;
            "properties": {};
        };
        "EndPoint": {
            "name": string;
            "properties": {};
        };
        "EndPointSpec": {
            "name": string;
            "properties": {
                "url": {
                    "name": string;
                };
                "needToSendResponse": {
                    "name": string;
                };
            };
        };
        "SecurityEnvironment": {
            "name": string;
            "properties": {};
        };
        "AuthentificationManager": {
            "name": string;
            "properties": {};
        };
        "SchemeInfo": {
            "name": string;
            "properties": {
                "parameterSpec": {
                    "name": string;
                };
            };
        };
        "SecurityScheme": {
            "name": string;
            "properties": {};
        };
        "SecurityAwareApiClient": {
            "name": string;
            "properties": {};
        };
        "SecuritySchemeHook": {
            "name": string;
            "properties": {};
        };
        "StatusCode": {
            "name": string;
            "properties": {};
        };
    };
};
export interface UniverseProvider {
    (key: string): Universe;
    availableUniverses(): string[];
    clean(): any;
}
export declare var getUniverse: UniverseProvider;
